@@ -164,7 +164,7 @@ class CentralReachCore(SitesCore):
             )
         return is_success
 
-    def apply_filter(self, filter_name: str, additional_params: str = ''):
+    def apply_filter(self, filter_name: str, additional_params: str = '', is_need_wait: bool = True):
         if self.browser.does_page_contain_element('//li/a[@data-click="openMenu"]'):
             if self.browser.find_element('//li/a[@data-click="openMenu"]').is_displayed():
                 self.click('//li/a[@data-click="openMenu"]')
@@ -188,8 +188,9 @@ class CentralReachCore(SitesCore):
             updated_url += additional_params
             self.browser.go_to(updated_url)
 
-        self.browser.wait_until_element_is_not_visible("//em[contains(., '<loading>')]", timedelta(seconds=45))
-        self.browser.wait_until_element_is_not_visible("//div[contains(@data-bind, 'loading()')]", timedelta(seconds=45))
+        if is_need_wait:
+            self.browser.wait_until_element_is_not_visible("//em[contains(., '<loading>')]", timedelta(seconds=45))
+            self.browser.wait_until_element_is_not_visible("//div[contains(@data-bind, 'loading()')]", timedelta(seconds=45))
 
     def is_no_results(self) -> bool:
         if self.browser.does_page_contain_element('//div[text()="No results matched your keywords, filters, or date range" and not(@style="display: none;")]'):
